@@ -123,7 +123,8 @@ using MeridianNNPtr = util::nn<MeridianPtr>;
  *
  * \remark Implements MERIDIAN from \ref WKT2
  */
-class PROJ_GCC_DLL Meridian : public common::IdentifiedObject {
+class PROJ_GCC_DLL Meridian : public common::IdentifiedObject,
+                              public io::IJSONExportable {
   public:
     //! @cond Doxygen_Suppress
     PROJ_DLL ~Meridian() override;
@@ -137,6 +138,9 @@ class PROJ_GCC_DLL Meridian : public common::IdentifiedObject {
     //! @cond Doxygen_Suppress
     PROJ_INTERNAL void _exportToWKT(io::WKTFormatter *formatter)
         const override; // throw(io::FormattingException)
+
+    PROJ_INTERNAL void _exportToJSON(io::JSONFormatter *formatter)
+        const override; // throw(FormattingException)
                         //! @endcond
 
   protected:
@@ -193,7 +197,8 @@ class PROJ_GCC_DLL CoordinateSystemAxis final : public common::IdentifiedObject,
         _isEquivalentTo(
             const util::IComparable *other,
             util::IComparable::Criterion criterion =
-                util::IComparable::Criterion::STRICT) const override;
+                util::IComparable::Criterion::STRICT,
+            const io::DatabaseContextPtr &dbContext = nullptr) const override;
 
     PROJ_INTERNAL void _exportToWKT(io::WKTFormatter *formatter, int order,
                                     bool disableAbbrev) const;
@@ -260,10 +265,11 @@ class PROJ_GCC_DLL CoordinateSystem : public common::IdentifiedObject,
 
     PROJ_INTERNAL virtual std::string getWKT2Type(bool) const = 0;
 
-    PROJ_INTERNAL bool
-    _isEquivalentTo(const util::IComparable *other,
-                    util::IComparable::Criterion criterion =
-                        util::IComparable::Criterion::STRICT) const override;
+    PROJ_INTERNAL bool _isEquivalentTo(
+        const util::IComparable *other,
+        util::IComparable::Criterion criterion =
+            util::IComparable::Criterion::STRICT,
+        const io::DatabaseContextPtr &dbContext = nullptr) const override;
     //! @endcond
 
   protected:
@@ -312,6 +318,11 @@ class PROJ_GCC_DLL SphericalCS final : public CoordinateSystem {
            const CoordinateSystemAxisNNPtr &axis2,
            const CoordinateSystemAxisNNPtr &axis3);
 
+    PROJ_DLL static SphericalCSNNPtr
+    create(const util::PropertyMap &properties,
+           const CoordinateSystemAxisNNPtr &axis1,
+           const CoordinateSystemAxisNNPtr &axis2);
+
   protected:
     PROJ_INTERNAL explicit SphericalCS(
         const std::vector<CoordinateSystemAxisNNPtr> &axisIn);
@@ -352,19 +363,27 @@ class PROJ_GCC_DLL EllipsoidalCS final : public CoordinateSystem {
     create(const util::PropertyMap &properties,
            const CoordinateSystemAxisNNPtr &axis1,
            const CoordinateSystemAxisNNPtr &axis2);
+
     PROJ_DLL static EllipsoidalCSNNPtr
     create(const util::PropertyMap &properties,
            const CoordinateSystemAxisNNPtr &axis1,
            const CoordinateSystemAxisNNPtr &axis2,
            const CoordinateSystemAxisNNPtr &axis3);
+
     PROJ_DLL static EllipsoidalCSNNPtr
     createLatitudeLongitude(const common::UnitOfMeasure &unit);
+
     PROJ_DLL static EllipsoidalCSNNPtr createLatitudeLongitudeEllipsoidalHeight(
         const common::UnitOfMeasure &angularUnit,
         const common::UnitOfMeasure &linearUnit);
+
     PROJ_DLL static EllipsoidalCSNNPtr
     createLongitudeLatitude(const common::UnitOfMeasure &unit);
 
+    PROJ_DLL static EllipsoidalCSNNPtr createLongitudeLatitudeEllipsoidalHeight(
+        const common::UnitOfMeasure &angularUnit,
+        const common::UnitOfMeasure &linearUnit);
+
     //! @cond Doxygen_Suppress
 
     /** \brief Typical axis order. */
@@ -623,7 +642,7 @@ class PROJ_GCC_DLL TemporalCS : public CoordinateSystem {
     INLINED_MAKE_SHARED
 
     PROJ_INTERNAL std::string
-    getWKT2Type(bool use2018Keywords) const override = 0;
+    getWKT2Type(bool use2019Keywords) const override = 0;
 
   private:
     TemporalCS(const TemporalCS &other) = delete;
@@ -661,7 +680,7 @@ class PROJ_GCC_DLL DateTimeTemporalCS final : public TemporalCS {
         const CoordinateSystemAxisNNPtr &axis);
     INLINED_MAKE_SHARED
 
-    PROJ_INTERNAL std::string getWKT2Type(bool use2018Keywords) const override;
+    PROJ_INTERNAL std::string getWKT2Type(bool use2019Keywords) const override;
 
   private:
     DateTimeTemporalCS(const DateTimeTemporalCS &other) = delete;
@@ -697,7 +716,7 @@ class PROJ_GCC_DLL TemporalCountCS final : public TemporalCS {
         const CoordinateSystemAxisNNPtr &axis);
     INLINED_MAKE_SHARED
 
-    PROJ_INTERNAL std::string getWKT2Type(bool use2018Keywords) const override;
+    PROJ_INTERNAL std::string getWKT2Type(bool use2019Keywords) const override;
 
   private:
     TemporalCountCS(const TemporalCountCS &other) = delete;
@@ -733,7 +752,7 @@ class PROJ_GCC_DLL TemporalMeasureCS final : public TemporalCS {
         const CoordinateSystemAxisNNPtr &axis);
     INLINED_MAKE_SHARED
 
-    PROJ_INTERNAL std::string getWKT2Type(bool use2018Keywords) const override;
+    PROJ_INTERNAL std::string getWKT2Type(bool use2019Keywords) const override;
 
   private:
     TemporalMeasureCS(const TemporalMeasureCS &other) = delete;
