@@ -555,6 +555,10 @@
 #define EPSG_NAME_PARAMETER_GEOCENTRIC_TRANSLATION_FILE \
     "Geocentric translation file"
 
+#define EPSG_NAME_PARAMETER_EPSG_CODE_FOR_INTERPOLATION_CRS \
+    "EPSG code for Interpolation CRS"
+#define EPSG_CODE_PARAMETER_EPSG_CODE_FOR_INTERPOLATION_CRS 1048
+
 /* ------------------------------------------------------------------------ */
 
 #define PROJ_WKT2_NAME_METHOD_HEIGHT_TO_GEOG3D \
@@ -582,6 +586,9 @@
 #define EPSG_CODE_METHOD_VERTICALGRID_PL_TXT 1101
 #define EPSG_NAME_METHOD_VERTICALGRID_PL_TXT "Vertical Offset by Grid Interpolation (PL txt)"
 
+#define EPSG_CODE_METHOD_VERTICALGRID_NRCAN_BYN 1112
+#define EPSG_NAME_METHOD_VERTICALGRID_NRCAN_BYN "Vertical Offset by Grid Interpolation (NRCan byn)"
+
 #define EPSG_NAME_PARAMETER_VERTICAL_OFFSET_FILE "Vertical offset file"
 #define EPSG_CODE_PARAMETER_VERTICAL_OFFSET_FILE 8732
 
@@ -616,6 +623,9 @@
 #define EPSG_CODE_METHOD_VERTICAL_OFFSET 9616
 #define EPSG_NAME_METHOD_VERTICAL_OFFSET "Vertical Offset"
 
+#define EPSG_CODE_METHOD_VERTICAL_OFFSET_AND_SLOPE 1046
+#define EPSG_NAME_METHOD_VERTICAL_OFFSET_AND_SLOPE "Vertical Offset and Slope"
+
 #define EPSG_CODE_METHOD_GEOGRAPHIC2D_OFFSETS 9619
 #define EPSG_NAME_METHOD_GEOGRAPHIC2D_OFFSETS "Geographic2D offsets"
 
@@ -642,6 +652,15 @@
 #define EPSG_NAME_PARAMETER_GEOID_UNDULATION "Geoid undulation"
 #define EPSG_CODE_PARAMETER_GEOID_UNDULATION 8604
 
+#define EPSG_NAME_PARAMETER_INCLINATION_IN_LATITUDE "Inclination in latitude"
+#define EPSG_CODE_PARAMETER_INCLINATION_IN_LATITUDE 8730
+
+#define EPSG_NAME_PARAMETER_INCLINATION_IN_LONGITUDE "Inclination in longitude"
+#define EPSG_CODE_PARAMETER_INCLINATION_IN_LONGITUDE 8731
+
+#define EPSG_NAME_PARAMETER_EPSG_CODE_FOR_HORIZONTAL_CRS "EPSG code for Horizontal CRS"
+#define EPSG_CODE_PARAMETER_EPSG_CODE_FOR_HORIZONTAL_CRS 1037
+
 /* ------------------------------------------------------------------------ */
 
 #define EPSG_CODE_METHOD_AFFINE_PARAMETRIC_TRANSFORMATION 9624
